@@ -1,12 +1,47 @@
 package Clustericious::RouteBuilder::Proxy;
 
-use strict;
-use warnings;
+=head1 NAME
+
+Clustericious::RouteBuilder::Proxy -- build proxy routes easily
+
+=head1 SYNOPSIS
+
+    use My::Object::Class;
+    use Clustericious::RouteBuilder;
+    use Clustericious::RouteBuilder::Proxy
+      "proxy" => {
+        to            => "http://google.com:80",
+        strip_prefix  => "/google",
+        -as           => "proxy_google",
+      },
+      "proxy" => {
+        app => 'MyServer',
+        -as => "proxy_local"
+      },
+      proxy_service => {  # Bulk mapping
+             services => { "froogle" => "http://froogle.com",
+                           "fraggle" => "http://fraggle.com" }
+      };
+
+    ...
+    get '/google/:somewhere'    => \&proxy_google;
+    get '/something/:somewhere' => \&proxy_local;
+    get '/:service/(*whatever)' => \&proxy_service;
+
+=head1 DESCRIPTION
+
+This package provides routes for proxying.  It rewrites
+urls by stripping prefixes, and passes the rest on by
+prepending a given url to the incoming request.
+
+=head1 TODO
+
+more documentation
+
+=cut
+
 use Clustericious::Log;
-
-# ABSTRACT: build proxy routes easily
-our $VERSION = '0.9940_04'; # VERSION
-
+use strict;
 
 use Sub::Exporter -setup => {
     exports => [
@@ -22,7 +57,7 @@ sub _build_proxy {
     my $destination   = $arg->{to};
     $destination = Clustericious::Config->new($arg->{app})->url if $arg->{app};
     die "Can't determine url for proxy route.\n" unless $destination;
-    my $dest_url = Mojo::URL->new($destination);
+    my $dest_url      = Mojo::URL->new($destination);
 
     return sub {
         my $self = shift;
@@ -44,9 +79,6 @@ sub _build_proxy {
             }
             $url->path->parts([@parts]);
         }
-        if (@{ $dest_url->path->parts } && $dest_url->scheme) {
-            unshift @{ $url->path->parts }, @{ $dest_url->path->parts };
-        }
 
         LOGDIE "recursive proxy " if $self->req->url->to_abs eq $url->to_abs;
 
@@ -106,72 +138,3 @@ sub _sanitize_url {
 }
 
 1;
-
-__END__
-=pod
-
-=head1 NAME
-
-Clustericious::RouteBuilder::Proxy - build proxy routes easily
-
-=head1 VERSION
-
-version 0.9940_04
-
-=head1 SYNOPSIS
-
-    use My::Object::Class;
-    use Clustericious::RouteBuilder;
-    use Clustericious::RouteBuilder::Proxy
-      "proxy" => {
-        to            => "http://google.com:80",
-        strip_prefix  => "/google",
-        -as           => "proxy_google",
-      },
-      "proxy" => {
-        app => 'MyServer',
-        -as => "proxy_local"
-      },
-      proxy_service => {  # Bulk mapping
-             services => { "froogle" => "http://froogle.com",
-                           "fraggle" => "http://fraggle.com" }
-      };
-
-    ...
-    get '/google/:somewhere'    => \&proxy_google;
-    get '/something/:somewhere' => \&proxy_local;
-    get '/:service/(*whatever)' => \&proxy_service;
-
-=head1 DESCRIPTION
-
-This package provides routes for proxying.  It rewrites
-URLs by stripping prefixes, and passes the rest on by
-prepending a given url to the incoming request.
-
-=head1 SUPER CLASS
-
-none
-
-=head1 SEE ALSO
-
-L<Clustericious>
-
-=head1 AUTHOR
-
-original author: Brian Duggan
-
-current maintainer: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Curt Tilmes
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by NASA GSFC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
